/*******************************************************************************
* File Name: ADC_Input_PM.c
* Version 3.0
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ADC_Input.h"


/***************************************
* Local data allocation
***************************************/

static ADC_Input_BACKUP_STRUCT  ADC_Input_backup =
{
    ADC_Input_DISABLED
};


/*******************************************************************************
* Function Name: ADC_Input_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ADC_Input_SaveConfig(void)
{
    /* All configuration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: ADC_Input_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ADC_Input_RestoreConfig(void)
{
    /* All congiguration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: ADC_Input_Sleep
********************************************************************************
*
* Summary:
*  This is the preferred routine to prepare the component for sleep.
*  The ADC_Input_Sleep() routine saves the current component state,
*  then it calls the ADC_Stop() function.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ADC_Input_backup - The structure field 'enableState' is modified
*  depending on the enable state of the block before entering to sleep mode.
*
*******************************************************************************/
void ADC_Input_Sleep(void)
{
    if((ADC_Input_PWRMGR_SAR_REG  & ADC_Input_ACT_PWR_SAR_EN) != 0u)
    {
        if((ADC_Input_SAR_CSR0_REG & ADC_Input_SAR_SOF_START_CONV) != 0u)
        {
            ADC_Input_backup.enableState = ADC_Input_ENABLED | ADC_Input_STARTED;
        }
        else
        {
            ADC_Input_backup.enableState = ADC_Input_ENABLED;
        }
        ADC_Input_Stop();
    }
    else
    {
        ADC_Input_backup.enableState = ADC_Input_DISABLED;
    }
}


/*******************************************************************************
* Function Name: ADC_Input_Wakeup
********************************************************************************
*
* Summary:
*  This is the preferred routine to restore the component to the state when
*  ADC_Input_Sleep() was called. If the component was enabled before the
*  ADC_Input_Sleep() function was called, the
*  ADC_Input_Wakeup() function also re-enables the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  ADC_Input_backup - The structure field 'enableState' is used to
*  restore the enable state of block after wakeup from sleep mode.
*
*******************************************************************************/
void ADC_Input_Wakeup(void)
{
    if(ADC_Input_backup.enableState != ADC_Input_DISABLED)
    {
        ADC_Input_Enable();
        #if(ADC_Input_DEFAULT_CONV_MODE != ADC_Input__HARDWARE_TRIGGER)
            if((ADC_Input_backup.enableState & ADC_Input_STARTED) != 0u)
            {
                ADC_Input_StartConvert();
            }
        #endif /* End ADC_Input_DEFAULT_CONV_MODE != ADC_Input__HARDWARE_TRIGGER */
    }
}


/* [] END OF FILE */
