/*******************************************************************************
* File Name: Control_Int_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Control_Int.h"

/* Check for removal by optimization */
#if !defined(Control_Int_Sync_ctrl_reg__REMOVED)

static Control_Int_BACKUP_STRUCT  Control_Int_backup = {0u};

    
/*******************************************************************************
* Function Name: Control_Int_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Control_Int_SaveConfig(void) 
{
    Control_Int_backup.controlState = Control_Int_Control;
}


/*******************************************************************************
* Function Name: Control_Int_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Control_Int_RestoreConfig(void) 
{
     Control_Int_Control = Control_Int_backup.controlState;
}


/*******************************************************************************
* Function Name: Control_Int_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Control_Int_Sleep(void) 
{
    Control_Int_SaveConfig();
}


/*******************************************************************************
* Function Name: Control_Int_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Control_Int_Wakeup(void)  
{
    Control_Int_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
