/*******************************************************************************
* File Name: Control_Interrupt_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Control_Interrupt.h"

/* Check for removal by optimization */
#if !defined(Control_Interrupt_Sync_ctrl_reg__REMOVED)

static Control_Interrupt_BACKUP_STRUCT  Control_Interrupt_backup = {0u};

    
/*******************************************************************************
* Function Name: Control_Interrupt_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Control_Interrupt_SaveConfig(void) 
{
    Control_Interrupt_backup.controlState = Control_Interrupt_Control;
}


/*******************************************************************************
* Function Name: Control_Interrupt_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Control_Interrupt_RestoreConfig(void) 
{
     Control_Interrupt_Control = Control_Interrupt_backup.controlState;
}


/*******************************************************************************
* Function Name: Control_Interrupt_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Control_Interrupt_Sleep(void) 
{
    Control_Interrupt_SaveConfig();
}


/*******************************************************************************
* Function Name: Control_Interrupt_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Control_Interrupt_Wakeup(void)  
{
    Control_Interrupt_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
