/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
/******************************************************************************
*                           THEORY OF OPERATION
* This project demonstrates how ADC is used to read the input voltage at 
* it's input and display it on the LCD.
* 
* The Potentiometer is connected to the input of the SAR ADC. ADC is 
* configured with 12 bit of resolution to measure the input voltage with 
* higher accuracy. ADC count is converted back to micro volts and 8 samples are 
* collected. After that the average of 8 samples is calculated and displayed
* on the LCD. 
*
* Hardware connection on the Kit
* Potentiometer - PORT 6[5] 
* LCD - PORT 2[0..6]
*******************************************************************************/
#include <project.h>
#include "stdio.h"

#define MAX_SAMPLE                  128
//#define MAX_SAMPLE                  8
//#define V_pot                       0
//#define I_feedback                  1



/* Variable to hold ADC count */
    int32 voltCount = 0;
    int32 iCount = 0;
    
    /* Variable to hold the result in millivolts converted from ADC counts */
    int32 mVolts = 0;
    int32 mAmps = 0;    

    /* Variable to count number of samples collected from ADC */
    uint8 sampleCount = 0;
    uint8 isampleCount = 0;
	
    /* Variable to hold cumulative samples */
    int32 voltSamples = 0;
    int32 ampsSamples = 0;
	
    /* Variable to hold the average volts for 8 samples */
    uint32 averageVolts = 0;
    uint32 averageAmps = 0;
    
    /* Variable to hold the input Voltage */
	uint32 Vin = 0;
    
    /* Variable to hold the display input Voltage */
	uint32 V_display = 0;
    
    /* Variable to hold the input Voltage that input to the DAC */
	uint32 Vin_DAC = 0;
    
    /* Variable to hold the value of feedback load current in voltage*/
    uint32 Iload = 0;
    
    /* Variable to hold the scaled value of feedback load current*/
    uint32 I_scaled = 0;
    
    /* Variable to hold the current feedback chanel Ichanel*/
    uint32 Ichanel = 1;
    
    /* Variable to hold total current feedback from all the chanels*/
    uint32 Itotal = 0;
    
    /* Character array to hold the micro volts*/
    char displayStr_Vin[10] = {'\0'};
    /* Character array to hold the micro amps*/
    char displayStr_Iload[10] = {'\0'};
    
    /*function prototype that convert the input voltage via ADC_Input*/
    uint32 convertinput(void);    
    
    /*function prototype that convert the input voltage via ADC_Feedback1*/
    uint32 convertfeedback(void);
    
    CY_ISR_PROTO (isr_1_Interrupt);
    
    
int main(void)
{
    isr_1_Start(); // enable the interrupt 
    
    CYGlobalIntEnable;      
    
    /* Start VDAC */
    VDAC8_1_Start();
    
    /* Start LCD and set position */
    LCD_Start();
    
    /* Start ADC and start conversion */
    ADC_Input_Start();
    
    /* Start ADC and start conversion */
    ADC_Feedback1_Start();
    
    /* Start the AMux*/
    
    AMux_1_Start();
    
     
    
    while(1)
    {
        
        /* Vin is the input voltage of the Opamp (0-2.5V).The averageVolts is 0-5000(mV)*/
        Vin = convertinput();   
        
        /* the purpose of this if statement is to stop the LCD jumping around by 
        only displaying the new value if there's any change > 5% of the current value*/        
        if ((Vin - V_display) > (V_display*0.05))
        {
            V_display = Vin;            
            
        }
        else 
        {
            /* Convert milli volts to string and display on the LCD. sprintf()
            *  function is standard library function defined in the stdio.h 
            *  header file */
            LCD_Position(0,1);
            LCD_PrintString("Vset");
            sprintf(displayStr_Vin,"%4ld mV",V_display);            
            LCD_Position(1,0);
            LCD_PrintString(displayStr_Vin); 
        }
        
   
        /* Vin value for ADC, because the input range of the DAC is 0-255, 
        16 is the scale factor that ensure the DAC outpout the voltage from 1-2500*/         
        Vin_DAC = V_display/20;        
        
        /* Output the new voltage to P0_6 to drive the collector of MOSFET*/
        VDAC8_1_SetValue(Vin_DAC);       
        
//        // Get the feedback current from the ADC_Feedback1
//        Iload= convertfeedback();
        
        // Get the sum of all the feedback current to Itotal
        while (Ichanel <= 2)
        {
            Control_Int_Write(0xff);  // set the value of the control reg to trigger the interrupt
            //isr_1_SetPending();
            Iload = convertfeedback();  // get the feedback current value from convertfeedback function
            Itotal = Itotal + Iload;    // add up to Itotal value
            Ichanel ++;                 // increase the Ichanel value
        }
                    
        
        /* the purpose of this if statement is to stop the LCD jumping around by 
        only displaying the new value if there's any change > 1% of the current value*/
        //if ((Iload-(I_display/20)) > ((I_display/20)*0.01))
        //if ((Iload-(I_scaled/10)) > (I_scaled*0.05/10))
        if (Itotal != (I_scaled*105/1000)) // if new value is 5% different than the current value then update new value
        {
            
            // The feedback signal is connected to only 1 shunt resistor, therefore we have to multiply by 10
            // 10 -due to 0.1Ohm resistor 
            I_scaled = Itotal * 10;
        }    
        else
        {        
            /* Convert milli volts to string and display on the LCD. sprintf()
            *  function is standard library function defined in the stdio.h 
            *  header file */
            LCD_Position(0,10);
            LCD_PrintString("Iload");
            sprintf(displayStr_Iload,"%4ld mA",I_scaled);            
            LCD_Position(1,8);
            LCD_PrintString(displayStr_Iload); 
        }
    }

}

   /* convert function that take an analog input and return the reading after doing averaging*/
    uint32 convertinput()
    {
       while(1)
        {        
//            /*Reset averageVolts*/
//            averageVolts = 0;
            
            /* Read ADC count and convert to milli volts */
            ADC_Input_StartConvert();
            ADC_Input_IsEndConversion(ADC_Input_WAIT_FOR_RESULT);
            voltCount = ADC_Input_GetResult16();
            mVolts = ADC_Input_CountsTo_mVolts(voltCount);
            
            /* Add the current ADC reading to the cumulated samples*/
            voltSamples = voltSamples + mVolts;

            sampleCount++;

            /* If 8 samples have been collected then average the samples and update the display*/
            if(sampleCount == MAX_SAMPLE)
            {
                averageVolts = voltSamples >> 8;
                voltSamples = 0;
                sampleCount = 0;    
                return averageVolts; //return the averageVolts after averaging
            }	
        }
    }
    /* convert function that take feedback voltage (feedback current*shunt res and return the reading after doing averaging*/
        
    uint32 convertfeedback()
    {
       while(1)
        {        
            
            /* Read ADC count and convert to milli volts */
            ADC_Feedback1_StartConvert();
            ADC_Feedback1_IsEndConversion(ADC_Feedback1_WAIT_FOR_RESULT);
            iCount = ADC_Feedback1_GetResult16();
            mAmps = ADC_Input_CountsTo_mVolts(iCount);
            
            /* Add the current ADC reading to the cumulated samples*/
            ampsSamples = ampsSamples + mAmps;

            isampleCount++;

            /* If 8 samples have been collected then average the samples and update the display*/
            if(isampleCount == MAX_SAMPLE)
            {
                averageAmps = ampsSamples >> 8;
                ampsSamples = 0;
                isampleCount = 0;    
                return averageAmps; //return the averageAmps after averaging
            }	
        }    
    }

/* [] END OF FILE */